@@ -30,6 +30,11 @@ func TestCreateClient(t *testing.T) {
 			provider: "Abacus",
 			exists:   true,
 		},
+		{
+			name:     "Existing provider - MiniMax",
+			provider: "MiniMax",
+			exists:   true,
+		},
 		{
 			name:     "Non-existent provider",
 			provider: "NonExistent",
