@@ -29,6 +29,7 @@ type PromptRequest struct {
 	ContextName  string            `json:"contextName"`
 	PatternName  string            `json:"patternName"`
 	StrategyName string            `json:"strategyName"`        // Optional strategy name
+	SessionName  string            `json:"sessionName"`         // Session name for multi-turn conversations
 	Variables    map[string]string `json:"variables,omitempty"` // Pattern variables
 }
 
@@ -55,6 +56,17 @@ func NewChatHandler(r *gin.Engine, registry *core.PluginRegistry, db *fsdb.Db) *
 	return handler
 }
 
+// HandleChat godoc
+// @Summary Stream chat completions
+// @Description Stream AI responses using Server-Sent Events (SSE)
+// @Tags chat
+// @Accept json
+// @Produce text/event-stream
+// @Param request body ChatRequest true "Chat request with prompts and options"
+// @Success 200 {object} StreamResponse "Streaming response"
+// @Failure 400 {object} map[string]string
+// @Security ApiKeyAuth
+// @Router /chat [post]
 func (h *ChatHandler) HandleChat(c *gin.Context) {
 	var request ChatRequest
 
@@ -120,6 +132,7 @@ func (h *ChatHandler) HandleChat(c *gin.Context) {
 					},
 					PatternName:      p.PatternName,
 					ContextName:      p.ContextName,
+					SessionName:      p.SessionName,    // Pass session name for multi-turn conversations
 					PatternVariables: p.Variables,      // Pass pattern variables
 					Language:         request.Language, // Pass the language field
 				}
